summaryrefslogtreecommitdiffstats
path: root/Source/cmVisualStudio10TargetGenerator.cxx
diff options
context:
space:
mode:
authorBen Boeckel <ben.boeckel@kitware.com>2023-12-26 16:42:42 (GMT)
committerBen Boeckel <ben.boeckel@kitware.com>2024-01-06 16:18:57 (GMT)
commit34f4423851a09aeccab8ca6e135c31de4bf149e0 (patch)
tree8d6a6da92b5efbf86594f46c45b17a13516ee87a /Source/cmVisualStudio10TargetGenerator.cxx
parentb03e3c5251596e597e81ad9cb0a435bf4675e6b7 (diff)
downloadCMake-34f4423851a09aeccab8ca6e135c31de4bf149e0.zip
CMake-34f4423851a09aeccab8ca6e135c31de4bf149e0.tar.gz
CMake-34f4423851a09aeccab8ca6e135c31de4bf149e0.tar.bz2
cmVisualStudio10TargetGenerator: fix typo in flag name
It is case insensitive, so this only matches the official flag name and still works.
Diffstat (limited to 'Source/cmVisualStudio10TargetGenerator.cxx')
-rw-r--r--Source/cmVisualStudio10TargetGenerator.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/Source/cmVisualStudio10TargetGenerator.cxx b/Source/cmVisualStudio10TargetGenerator.cxx
index 4860d9a..e0be04d 100644
--- a/Source/cmVisualStudio10TargetGenerator.cxx
+++ b/Source/cmVisualStudio10TargetGenerator.cxx
@@ -2784,7 +2784,7 @@ void cmVisualStudio10TargetGenerator::OutputSourceSpecificFlags(
isCppModule = true;
if (shouldScanForModules &&
this->GlobalGenerator->IsScanDependenciesSupported()) {
// ScanSourceforModuleDependencies uses 'cl /scanDependencies' and
// can distinguish module interface units and internal partitions.
compileAsPerConfig = "CompileAsCpp";
} else {
@@ -2856,9 +2856,9 @@ void cmVisualStudio10TargetGenerator::OutputSourceSpecificFlags(
clOptions.AddFlag("CompileAs", compileAsPerConfig);
}
if (shouldScanForModules) {
- clOptions.AddFlag("ScanSourceforModuleDependencies", "true");
+ clOptions.AddFlag("ScanSourceForModuleDependencies", "true");
} else {
- clOptions.AddFlag("ScanSourceforModuleDependencies", "false");
+ clOptions.AddFlag("ScanSourceForModuleDependencies", "false");
}
if (noWinRT) {
clOptions.AddFlag("CompileAsWinRT", "false");
@@ -2784,7 +2784,7 @@ void cmVisualStudio10TargetGenerator::OutputSourceSpecificFlags(
if (shouldScanForModules &&
this->GlobalGenerator->IsScanDependenciesSupported()) {
- // ScanSourceforModuleDependencies uses 'cl /scanDependencies' and
+ // ScanSourceForModuleDependencies uses 'cl /scanDependencies' and
// can distinguish module interface units and internal partitions.
compileAsPerConfig = "CompileAsCpp";